@@ -1,29 +1,69 @@
 <?php
 
-/*
- * spamrule:  $Id: config.php,v 1.6 2003/04/08 23:58:08 shaug Exp $
- * (c) 2002 O'Shaughnessy Evans <shaug-spamrule @ wumpus.org>
+/**
+ * spamrule/config.php
+ * 
+ * User configuration page for the SquirrelMail "spamrule" plugin,
+ * which provides users with simple management of email filter groups.
+ * 
+ * @copyright Copyright (c) 2002-2007 O'Shaughnessy Evans <shaug-sqml @ wumpus.org>
+ * @version $Id: config.php,v 1.19 2007/09/11 23:55:11 shaug Exp $
+ * @license http://opensource.org/licenses/artistic-license-2.0.php
+ * @package plugins
+ * @subpackage spamrule
  */
 
-$SPAMRULE_VERSION = '0.2';
-
 
 /*
  * Filter Installation Config
  * 
  * In the options below, you should configure the name of the host that
- * provides IMAP users with FTP access to their accounts.  Each user must
- * have their own account with the ability to change their mail forward
- * file and their mail filtering file.
+ * provides the IMAP users with FTP access to their accounts.  Each user
+ * must have their own account with the ability to change their mail
+ * forward file and their mail filtering file.
  * 
  * If this isn't an option, you can configure a local program to run when
  * installing filters by setting $SPAMRULE_INSTALL['command'].  If that 
  * variable is set, it will be used instead of FTP.
+ * 
+ * By default:
+ *   - the plugin will use localhost as the FTP server,
+ *   - .forward as the user's mail forward file,
+ *   - maildrop as the email filter, installed in /usr/local/bin/maildrop
+ *   - .mailfilter as the path to the user's maildrop config
+ *   - .mailfilters as the subdir where the user's maildrop pattern files go
+ *   - /usr/local/etc/maildroprcs as the include dir for enabling
+ *     individual maildrop filters
+ * 
+ * There are a lot of individual maildrop filters that are configured later
+ * in this file.  If you want to use those, then you may also want to install
+ * the maildroprc and maildroprcs that are included in this distribution
+ * under the "maildrop" directory.  Copy them both to /usr/local/etc or
+ * wherever your maildrop binary is compiled to look.
+ * 
+ * Read through this config file carefully.  There's a lot you can configure,
+ * and it looks complicated, but the end result for users should be very
+ * clear and simple.
  */
 
+
+// make these global so that the vlogin plugin can override options
+// and other files can access them
+global $SPAMRULE_OPTS, $SPAMRULE_INSTALL, $domain, $javascript_on, $username;
+sqsession_register($SPAMRULE_OPTS, 'SPAMRULE_OPTS');
+sqsession_register($SPAMRULE_INSTALL, 'SPAMRULE_INSTALL');
+sqgetGlobalVar('domain', $domain, SQ_SESSION);
+sqgetGlobalVar('javascript_on', $javascript_on, SQ_SESSION);
+sqgetGlobalVar('username', $username, SQ_SESSION);
+
+
 // The host that stores user mail filter info:
 //  Each user with an IMAP account must have the same login and password here.
-$SPAMRULE_FTPHOST = 'localhost';
+// Don't override this if it's already set so that the vlogin plugin can
+// define it.
+if (empty($SPAMRULE_OPTS['ftphost'])) {
+    $SPAMRULE_OPTS['ftphost'] = 'localhost';
+}
 
 // User mail filter info:
 //
@@ -42,20 +82,23 @@ $SPAMRULE_INSTALL['filter_string'] =
 // What is the name of the user's filter file?
 //  for sendmail or postfix, it would be .forward
 //  for qmail, .qmail
-$SPAMRULE_INSTALL['forward_file']    = '.qmail';
+$SPAMRULE_INSTALL['forward_file']    = '.forward';
 // What should the filter file contain?  (make sure to include the newline)
-$SPAMRULE_INSTALL['forward_string']  = '| /usr/local/bin/maildrop';
+//$SPAMRULE_INSTALL['forward_string']  = '| /usr/local/bin/maildrop';
+$SPAMRULE_INSTALL['forward_string']  = '"|/usr/local/bin/maildrop"';
 // What pattern will match the forward filter string?
-$SPAMRULE_INSTALL['forward_pattern'] = '^\| */usr/local/bin/maildrop';
+//$SPAMRULE_INSTALL['forward_pattern'] = '^\| */usr/local/bin/maildrop';
+$SPAMRULE_INSTALL['forward_pattern'] = '^\"?\| */usr/local/bin/maildrop\"?';
 // What pattern will match the local inbox?
-$SPAMRULE_INSTALL['inbox_pattern']   = '^\.\/Incoming';
+//$SPAMRULE_INSTALL['inbox_pattern']   = '^\.\/Incoming';
+$SPAMRULE_INSTALL['inbox_pattern']   = "^\.$username";
 
 // The command to run to install the new set of filters:
 //  %s will be replaced with the names of all the filters being installed,
 //  as named in the keys of $SPAMRULE_FILTERS[].
 /*
 $SPAMRULE_INSTALL['command'] =
- "/usr/local/www/libexec/save-mailfilters -l {$GLOBALS['username']} %s";
+ "/usr/local/www/libexec/save-mailfilters -l {$username} %s";
 */
 
 
@@ -74,7 +117,7 @@ $SPAMRULE_INSTALL['command'] =
  *   uninstall:  If defined, this command will be run whenever the filter has
  *               *not* been selected for use.
  */
-$SPAMRULE_FILTERS = array(
+$SPAMRULE_OPTS['filters'] = array(
   'only-from'  => array(
     'title'    => 'Only From',
     'text'     => 'Only accept mail from an <em>Allowed Sender</em>.  Mail '.
@@ -83,7 +126,7 @@ $SPAMRULE_FILTERS = array(
 		  'note!</em>  This supercedes all other filters.  IF YOU '.
 		  'ENABLE THIS, NONE OF YOUR OTHER FILTERS WILL BE USED.'.
 		  '<div align=right><small><em>Update your:  '.
-                  ( $GLOBALS['javascript_on']
+                  ( $javascript_on
                     ? '<a href="javascript:void(0)" onclick="subwin'.
                       '(\'options.php?action=editlist&list=allowed_senders\', '.
                       '\'sr_editlist\', 500, 600)">'
@@ -99,7 +142,7 @@ $SPAMRULE_FILTERS = array(
                   'from them will always go through, no matter what other '.
 		  'filters are in use.'.
 		  '<div align=right><small><em>Update your:  '.
-                  ( $GLOBALS['javascript_on']
+                  ( $javascript_on
                     ? '<a href="javascript:void(0)" onclick="subwin'.
                       '(\'options.php?action=editlist&list=allowed_senders\', '.
                       '\'sr_editlist\', 450, 450)">'
@@ -116,7 +159,7 @@ $SPAMRULE_FILTERS = array(
                   'is include a secret word in the <b>Subject</b> and the '.
                   'message will get past your filters.'.
                   '<div align=right><small><em>Update your:  '.
-                  ( $GLOBALS['javascript_on']
+                  ( $javascript_on
                     ? '<a href="javascript:void(0)" onclick="subwin'.
                       '(\'options.php?action=editlist'.
                       '&list=subject_passwords\', \'sr_editlist\', 450, 450)">'
@@ -127,7 +170,7 @@ $SPAMRULE_FILTERS = array(
   ),
   'only-to-cc' => array(
     'title'    => 'Only To Me',
-    'text'     => 'If "'. $GLOBALS['username'].  '@aloha.net" or one of your '.
+    'text'     => 'If "'. $username. '@aloha.net" or one of your '.
                   '<em>aliases</em> isn\'t in the <b>To</b> or <b>Cc</b> '.
                   'headers, send the message to your "Junk" mailbox.  This '.
                   '<em>may</em> catch some mailing lists, so if you\'re '.
@@ -135,15 +178,15 @@ $SPAMRULE_FILTERS = array(
                   'filter and add the list sender to your <em>Allowed Senders'.
                   '</em> before using this.'.
 		  '<div align=right><small><em>Update your:  '.
-                  ( $GLOBALS['javascript_on']
+                  ( $javascript_on
                     ? '<a href="javascript:void(0)" onclick="subwin'.
                       '(\'options.php?action=editlist&list='.
                        'allowed_recipients\', \'sr_editlist\', 450, 450)">'
                     : '<a href="options.php?action=editlist&list='.
                       'allowed_recipients" target="_blank">'
                   ).
-		  'aliases</a> '.
-                  ( $GLOBALS['javascript_on']
+		  'Aliases</a> '.
+                  ( $javascript_on
                     ? '<a href="javascript:void(0)" onclick="subwin'.
                       '(\'options.php?action=editlist&list=allowed_senders\', '.
                       '\'sr_editlist\', 450, 450)">'
@@ -183,12 +226,21 @@ $SPAMRULE_FILTERS = array(
                   'programs like Outlook or Eudora.  Spammers, on the other '.
                   'hand, don\'t seem to care quite as much.'
   ),
+  'reject-me' => array(
+    'title'    => 'Never From Me',
+    'text'     => 'Never accept mail that was sent from your own address, "'.
+                  $username. '@aloha.net."  Some spammers will '.
+		  'fake the sender and make it appear that the message is '.
+		  'coming <em>from</em> you as well as being sent <em>to</em> '.
+		  'you.  Unless you send yourself email, this is a safe way '.
+		  'to stop some junk from getting through.'
+  ),
   'reject-from' => array(
     'title'    => 'Never From',
     'text'     => 'Filter any mail from a <em>Blocked Sender</em>.  Add the '.
                   'addresses of people from whom you never want to get mail.'.
 		  '<div align=right><small><em>Update your:  '.
-                  ( $GLOBALS['javascript_on']
+                  ( $javascript_on
                     ? '<a href="javascript:void(0)" onclick="subwin'.
                       '(\'options.php?action=editlist&list=blocked_senders\','.
                       ' \'sr_editlist\', 450, 450)">'
@@ -203,7 +255,7 @@ $SPAMRULE_FILTERS = array(
                   'Edit your list of subject words, then any mail with a '.
                   'subject that matches your list will be filtered.'.
 		  '<div align=right><small><em>Update your:  '.
-                  ( $GLOBALS['javascript_on']
+                  ( $javascript_on
                     ? '<a href="javascript:void(0)" onclick="subwin'.
                       '(\'options.php?action=editlist&list=blocked_subjects\','.
                       ' \'sr_editlist\', 450, 450)">'
@@ -212,6 +264,7 @@ $SPAMRULE_FILTERS = array(
                   ).
 		  'Blocked Subjects</a></em></small></div>'
   ),
+/*
   'spamassassin' => array(
     'title'    => 'SpamAssassin',
     'text'     => 'Use <a href="http://www.spamassassin.org" target="_blank">'.
@@ -221,22 +274,28 @@ $SPAMRULE_FILTERS = array(
                   'see a description of why it was caught in the first part '.
                   'of your message.'
   ),
+ */
+/*
   'GLOBAL' => array(
     'title'    => 'System-Wide Filters',
-    'text'     => 'These filters are used for all incoming mail.  '.
-                  'They utilize blacklists that block mail from known '.
-                  'Internet abusers and stop a lot of spam before it '.
+    'text'     => 'These filters are used for all incoming mail at '.
+                  'aloha.net.  They utilize various tools to stop junk mail, '.
+                  'including sophisticated tests to look for common spam '.
+                  'characteristics and blacklists that block mail from known '.
+                  'Internet abusers and stop a lot of junk before it '.
                   'gets inside the HOL computers.  Occasionally, '.
                   'though, they may block legitimate email.  '.
                   'We <em>strongly</em> recommend that you leave this '.
                   'enabled, but if you know that mail from a contact is '.
                   'getting blocked, you may want to opt out by disabling '.
-                  'this option via the "Custom" filters.',
-    'install'   => '/usr/local/www/libexec/spamfriend-del '.
-                   $GLOBALS['username'],
-    'uninstall' => '/usr/local/www/libexec/spamfriend-add '.
-                   $GLOBALS['username']
+                  'this option via the "Custom" filters.  If you would like '.
+                  'to learn more about these filters, please see '.
+                  '<a href="http://www.aloha.net/support/antispam.php" '.
+                  'target="_blank">our Anti-Spam page</a>.',
+    'install'   => '/usr/local/www/libexec/spamfriend-del '. $username,
+    'uninstall' => '/usr/local/www/libexec/spamfriend-add '. $username,
   ),
+ */
 /*
  *   'FORWARD' => array(
  *     'default'  => FALSE,
@@ -265,22 +324,26 @@ $SPAMRULE_FILTERS = array(
  * default, where they can choose exactly which filters they want to use.
  */
 // Name the default group here (should be one of the keys in $SPAMRULE_GROUPS)
-$SPAMRULE_DEFGROUP = 'CAREFUL';
+$SPAMRULE_OPTS['default_group'] = 'CAREFUL';
 // Array of arrays, each containing a group of filters that the user can
 // select.
-$SPAMRULE_GROUPS = array(
+$SPAMRULE_OPTS['groups'] = array(
   'ALL_OFF' => array(
     'title'   => 'No Personal Filtering',
-    'filters' => array('GLOBAL'),
+    //'filters' => array('GLOBAL'),
+    'filters' => array(),
     'text'    => <<<EOtext
   Don't do any special filtering.<br>
+  <!--
   <small><i>Your mail will still go through the system-wide filters (see
   the description under "Custom").</i></small>
+  -->
 EOtext
   ),
   'CAREFUL' => array(
     'title'   => 'Careful',
-    'filters' => array('only-to-cc', 'reject-ad', 'reject-bulk', 'GLOBAL'),
+    //'filters' => array('only-to-cc', 'reject-ad', 'reject-bulk', 'GLOBAL'),
+    'filters' => array('only-to-cc', 'reject-ad', 'reject-bulk'),
     'text'    => <<<EOtext
   Only filter out messages that clearly look like junk mail.<br>
   <small><i>If you have any other email addresses that go to this mailbox, make sure to return here and customize your aliases when you're finished.
@@ -291,8 +354,8 @@ EOtext
     'title'   => 'Strict',
     'filters' => array('always-from', 'subject-passwords', 'only-to-cc',
                        'reject-ad', 'reject-bulk', 'reject-not822',
-                       'reject-from', 'reject-subject', 'spamassassin',
-                       'GLOBAL'),
+                       'reject-from', 'reject-subject'),
+                        #'spamassassin', 'GLOBAL'),
     'text'    => <<<EOtext
   Be aggressive:  use all the available filters.<br>
   <small><i>... including your own lists of Allowed Senders, Blocked Senders,
@@ -303,13 +366,14 @@ EOtext
   'CUSTOM' => array(
     'title'   => 'Custom',
     'filters' => array('only-to-cc', 'reject-ad', 'reject-bulk',
-                       'reject-not822', 'GLOBAL'),
+                       'reject-not822'), #'GLOBAL'),
     'text'    => <<<EOtext
   Choose your own set of filters.<br>
   <small><i>
-  Use this to select from all the filters we have available, or to opt out
+  Use this to select from all the filters we have available.
+  <!-- , or to opt out
   of the system-wide filters if you're having trouble getting mail from
-  someone.
+  someone. -->
   </i></small>
 EOtext
   )
@@ -332,18 +396,20 @@ EOtext
  *   $SPAMRULE_OPTS[<array>]['header']
  *   $SPAMRULE_OPTS[<array>]['footer']
  * 
- *   $SPAMRULE_OPTS[<array>]['file']
- *   $SPAMRULE_OPTS[<array>]['title']
- *   $SPAMRULE_OPTS[<array>]['default']
+ *   For the lists that users can maintain:
+ *   $SPAMRULE_OPTS[<array>]['file'] -- where the list is kept (can be relative)
+ *   $SPAMRULE_OPTS[<array>]['type'] -- if "email", then only addrs are allowed
+ *   $SPAMRULE_OPTS[<array>]['title'] -- title of the editing window page
+ *   $SPAMRULE_OPTS[<array>]['default'] -- how to initialize the file's contents
  */
 
 // Description of the first page, showing the filter group selection form:
-$SPAMRULE_OPTS['groups']['header'] = <<<EOdesc
+$SPAMRULE_OPTS['groupsel']['header'] = <<<EOdesc
   <p>Here you can control the way your incoming mail will be filtered.
   All messages caught by the rules you select will be delivered to your
   "Junk" mail folder.</p>
 EOdesc;
-$SPAMRULE_OPTS['groups']['footer'] = <<<EOdesc
+$SPAMRULE_OPTS['groupsel']['footer'] = <<<EOdesc
   <div align=left><p>
   <em>Please note:</em><ul>
   <li>Messages in your "Trash" mail folder <u>do not</u> count against your
@@ -386,6 +452,8 @@ $SPAMRULE_OPTS['custom']['header'] = <<<EOheader
   <p>Here you can choose exactly which filters you want to use.  If you
   customized your filters before now, your old settings will already be loaded.
   If this is your first time, our recommended list will be selected.</p>
+  <p><strong>Make sure you press &quot;Finish&quot; to save your changes.
+  </strong></p>
 EOheader;
 $SPAMRULE_OPTS['custom']['footer'] = <<<EOfooter
   <p><a href="options.php">Back to the beginning</a></p>
@@ -394,6 +462,7 @@ EOfooter;
 // Some custom filter subpages:
 // ... for editing the list of senders from whom we'll *always* accept mail
 $SPAMRULE_OPTS['allowed_senders']['file'] = '.mailfilters/senders+';
+$SPAMRULE_OPTS['allowed_senders']['type'] = 'email';
 $SPAMRULE_OPTS['allowed_senders']['title'] = 'Allowed/Exclusive Senders';
 $SPAMRULE_OPTS['allowed_senders']['anchor'] = TRUE;
 $SPAMRULE_OPTS['allowed_senders']['header'] = <<<EOdesc
@@ -401,9 +470,9 @@ $SPAMRULE_OPTS['allowed_senders']['header'] = <<<EOdesc
   <p align=left>
      Here you can list people from whom you <strong><em>always</em></strong>
      want to get email, regardless of your other Spam Filters.  For example,
-     if you add "<tt>a_good_friend@{$GLOBALS['domain']}</tt>", then any mail
+     if you add "<tt>a_good_friend@{$domain}</tt>", then any mail
      from your friend will always go directly to your Inbox; if you just add
-     "<tt>@{$GLOBALS['domain']}</tt>", then mail from anyone at your
+     "<tt>@{$domain}</tt>", then mail from anyone at your
      friend's domain will be allowed through.  If you've chosen the
      <em>Only From</em> filter, then you'll <strong>only</strong> get mail
      from these people, and <strong>none from anyone else</strong>.  If
@@ -411,7 +480,7 @@ $SPAMRULE_OPTS['allowed_senders']['header'] = <<<EOdesc
      always go to your Inbox, but mail from other people may also get through.
   </p>
 EOdesc;
-$SPAMRULE_OPTS['allowed_senders']['footer'] = $GLOBALS['javascript_on']
+$SPAMRULE_OPTS['allowed_senders']['footer'] = $javascript_on
  ? '<p>[ <a href="javascript:window.close()">Close</a> ]</p>'
  : '';
 /*
@@ -422,10 +491,11 @@ $SPAMRULE_OPTS['allowed_senders']['footer'] = <<<EOfooter
 EOfooter;
 */
 //$SPAMRULE_OPTS['allowed_senders']['default'] = 
-// $GLOBALS['username']. '@'. $GLOBALS['domain'];
+// $username. '@'. $domain;
 
 // ... for editing the list of users from whom we'll *never* accept mail
 $SPAMRULE_OPTS['blocked_senders']['file'] = '.mailfilters/senders-';
+$SPAMRULE_OPTS['blocked_senders']['type'] = 'email';
 $SPAMRULE_OPTS['blocked_senders']['title'] = 'Blocked Senders';
 $SPAMRULE_OPTS['blocked_senders']['anchor'] = TRUE;
 $SPAMRULE_OPTS['blocked_senders']['header'] = <<<EOdesc
@@ -442,13 +512,14 @@ $SPAMRULE_OPTS['blocked_senders']['footer']
 
 // ... for editing the list of users that we use as aliases in only-to-cc
 $SPAMRULE_OPTS['allowed_recipients']['file'] = '.mailfilters/recipients+';
+$SPAMRULE_OPTS['allowed_recipients']['type'] = 'email';
 $SPAMRULE_OPTS['allowed_recipients']['title'] = 'Allowed Recipients';
 $SPAMRULE_OPTS['allowed_recipients']['anchor'] = TRUE;
 $SPAMRULE_OPTS['allowed_recipients']['header'] = <<<EOdesc
   <p align=center><u>Allowed Recipients</u></p>
   <p align=left>
      Here you can list alternative addresses, a.k.a. "aliases", that get sent
-     to <em>{$GLOBALS['username']}@aloha.net</em>.  If you are forwarding
+     to <em>{$username}@aloha.net</em>.  If you are forwarding
      mail from other Internet Providers to your aloha.net account, or you have
      an alias or mailbox-only account with us, and you chose the <em>Only To
      Me</em> filter, we recommend that you add those other addresses here.
